        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
}
