        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 21 <br>1,3,4,6,8,14,15,17,20,23,25,29,30,35,36,38,39,40,44,45,48';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 18 <strong>control</strong><br>0,9,10,11,12,16,19,22,27,28,31,32,34,37,41,46,47,49';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260618 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 12 <br>2,5,7,13,18,21,24,26,33,42,43,50';}
}
